Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "JmolJDXMOLReader");
;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
